use chrono::prelude::*;
use iced::widget::{container, row, text};
use iced::{Background, Border, Color, Element, Font, Length, Task};

use iced_layershell::build_pattern::{application, MainSettings};
use iced_layershell::reexport::Anchor;
use iced_layershell::settings::LayerShellSettings;
use iced_layershell::to_layer_message;

fn main() -> iced_layershell::Result {
    let settings = MainSettings {
        layer_settings: LayerShellSettings {
            size: Some((1200, 30)),
            anchor: Anchor::Bottom,
            margin: (0, 0, 10, 0),
            exclusive_zone: 40,
            ..Default::default()
        },
        default_font: Font::with_name("VictorMono Nerd Font"),
        ..Default::default()
    };

    application(Panel::namespace, Panel::update, Panel::view)
        .settings(settings)
        .style(Panel::style)
        .run_with(Panel::new)
}

struct Panel {
    apps: Vec<String>,
}

#[to_layer_message]
#[derive(Debug, Clone)]
enum Message {
    Launch(usize),
}

impl Panel {
    fn new() -> (Self, Task<Message>) {
        (Self { apps: vec![] }, Task::none())
    }
    fn namespace(&self) -> String {
        String::from("bottom panel")
    }

    fn update(&mut self, message: Message) -> Task<Message> {
        match message {
            Message::Launch(index) => Task::none(),
            _ => unreachable!(),
        }
    }

    fn view(&self) -> Element<Message> {
        // let bottom_vec: Vec<Element<Message>> = self
        //     .apps
        //     .iter()
        //     .enumerate()
        //     .map(|(index, app)| app.view(index, false))
        //     .collect();

        let datetime: DateTime<Local> = Local::now();

        let clock = text!("{}", datetime.format("%a %b %e, %r"));
        let clock = clock.color(Color::parse("#e2e4e5").unwrap());

        // let row = row(bottom_vec);
        container(clock)
            .style(|t: &iced::Theme| {
                container::rounded_box(t)
                    .border(Border::default().rounded(20))
                    .background(
                        Background::Color(Color::parse("#282a36").unwrap()).scale_alpha(0.95),
                    )
            })
            .center(Length::Fill)
            .into()
    }

    fn style(&self, theme: &iced::Theme) -> iced_layershell::Appearance {
        use iced_layershell::Appearance;
        Appearance {
            background_color: Color::TRANSPARENT,
            text_color: theme.palette().text,
        }
    }
}
